==> monitoring_plugins-1.0.2.tar.gz: monitoring_plugins-1.0.2/README.md <==
Monitoring plugins
==================
Monitoring-plugins are the check plugins for monitoring.

Copyright (c) 2020 Fabian Fröhlich <mail@confgen.org> [https://icinga2.confgen.org](https://icinga2.confgen.org)

Full License Information see  [https://github.com/f-froehlich/monitoring-plugins/blob/master/LICENSE](LICENSE) file in root directory of this source code and License section of this File.

# Donate
This project needs donations. Please check out [https://icinga2.confgen.org/Donate](https://icinga2.confgen.org/Donate) for details.


# Quick setup
See our [documentation](https://icinga2.confgen.org) for details.

## Required
* install python 3.7 (other versions may also work)
* install python3-pip
* `pip3 install --upgrade monitoring-plugins`


# License
This section contains the additional terms of the AGPLv3 license agreement, a copy of the AGPLv3 is included in the [LICENSE](https://github.com/f-froehlich/monitoring-plugins/blob/master/LICENSE) file.

1. Adaptation of the [https://github.com/f-froehlich/monitoring-plugins/blob/master/REDME.md](README.md) is prohibited. The file must also be included with each copy without any modification. 

2. Adjustments of any kind must be listed in the attached [https://github.com/f-froehlich/monitoring-plugins/blob/master/CHANGELOG.md](CHANGELOG.md) file. It is sufficient to name the change and the reason for the change here and to give appropriate references to the processing in the source code at the appropriate place.

3. All edited copies must be made available on [github](https://github.com). You have to fork the original repository or use a fork from the original repository.

4. You have to place the following link on your Homepage in a suitable place, if you using this software ***not*** only for your own Servers, Applications, ...:

    ```html
    We using monitoring tools from <a href="https://icinga2.confgen.org">Fabian Fr&ouml;hlich</a>
   ```

    The wording is decisive here, so another language may be used. Attributes of the link may also be adjusted, but the link must be followable by web crawlers (e.g. Googlebot).

    Furthermore, the imprint has to include a clear reference to the original github repository [https://github.com/f-froehlich/monitoring-plugins](https://github.com/f-froehlich/monitoring-plugins) as well as the link mentioned above in the body text.
    
5. You are not allowed to earn money with this tool.

==> monitoring_plugins-2.0.0.post1.tar.gz: monitoring_plugins-2.0.0.post1/README.md <==
Monitoring plugins
==================
Monitoring-plugins are the check plugins for monitoring.

Copyright (c) 2020 Fabian Fröhlich <mail@confgen.org> [https://icinga2.confgen.org](https://icinga2.confgen.org)

Full License Information see  [https://github.com/f-froehlich/monitoring-plugins/blob/master/LICENSE](LICENSE) file in root directory of this source code and License section of this File.

# Donate
This project needs donations. Please check out [https://icinga2.confgen.org/Donate](https://icinga2.confgen.org/Donate) for details.


# Quick setup
See our [documentation](https://icinga2.confgen.org) for details.

## Required
* install python 3.7 (other versions may also work)
* install python3-pip
* `pip3 install --upgrade monitoring-plugins --target=/usr/local/monitoring`


# License
This section contains the additional terms of the AGPLv3 license agreement, a copy of the AGPLv3 is included in the [LICENSE](https://github.com/f-froehlich/monitoring-plugins/blob/master/LICENSE) file.

1. Adaptation of the [https://github.com/f-froehlich/monitoring-plugins/blob/master/REDME.md](README.md) is prohibited. The file must also be included with each copy without any modification. 

2. Adjustments of any kind must be listed in the attached [https://github.com/f-froehlich/monitoring-plugins/blob/master/CHANGELOG.md](CHANGELOG.md) file. It is sufficient to name the change and the reason for the change here and to give appropriate references to the processing in the source code at the appropriate place.

3. All edited copies must be made available on [github](https://github.com). You have to fork the original repository or use a fork from the original repository.

4. You have to place the following link on your Homepage in a suitable place, if you using this software ***not*** only for your own Servers, Applications, ...:

    ```html
    We using monitoring tools from <a href="https://icinga2.confgen.org">Fabian Fr&ouml;hlich</a>
   ```

    The wording is decisive here, so another language may be used. Attributes of the link may also be adjusted, but the link must be followable by web crawlers (e.g. Googlebot).

    Furthermore, the imprint has to include a clear reference to the original github repository [https://github.com/f-froehlich/monitoring-plugins](https://github.com/f-froehlich/monitoring-plugins) as well as the link mentioned above in the body text.
    
5. You are not allowed to earn money with this tool.
